var map;
require([
	        "dojo/dom-construct",
	        "esri/map",
	        "esri/layers/FeatureLayer",
	        "esri/symbols/SimpleMarkerSymbol",
	        "esri/symbols/SimpleLineSymbol",
	        "esri/geometry/Point",
	        "dojo/_base/Color",
	        "esri/graphic",
	        "esri/symbols/Font",
	        "esri/symbols/TextSymbol",
	        "esri/geometry/Extent",
	        "esri/dijit/Legend",
	        "esri/dijit/Geocoder",
	        "esri/InfoTemplate",
	        "dojo/domReady!"
	      ], function(
	          domConstruct,
	          Map,
	          FeatureLayer,
	          SimpleMarkerSymbol,
	          SimpleLineSymbol,
	          Point,
	          Color,
	          Graphic,
	          Font,
	          TextSymbol,
	          Extent,
		  Legend,
	          Geocoder,
	          InfoTemplate
        ) {
			var bounds = new Extent({
			              "xmin":GetParam("xmin"),
			              "ymin":GetParam("ymin"),
			              "xmax":GetParam("xmax"),
			              "ymax":GetParam("ymax"),
			              "spatialReference":{"wkid":28992}
			            });

			map = new Map("map", {
			      extent: bounds
			    });

			var url_base = GetParam("kaart_og");
			var url_ond = GetParam("kaart_ow");

			var basemap = new esri.layers.ArcGISTiledMapServiceLayer(url_base,{opacity:0.6});
			map.addLayer(basemap);

			var infoTemplate = new esri.InfoTemplate();
			     infoTemplate.setTitle(GetParam("popup_title"));
			     infoTemplate.setContent( GetParam("popup_content") );

			var fl = new esri.layers.FeatureLayer(url_ond,{
                          mode: esri.layers.FeatureLayer.MODE_SNAPSHOT,
                          infoTemplate:infoTemplate,
                          outFields:[GetParam("output_fields"),GetParam("output_fields2")]
			              }
			);
			
			map.addLayer(fl);

			var legendDijit = new esri.dijit.Legend({
				map: map,
				layerInfos:
				   [{
					 "layer": fl,
					 "title": GetParam("leg_title")
				   }]
			   }, "legenddiv");
			legendDijit.startup();

			var gc = [{
			     url: "https://services.arcgisonline.nl/arcgis/rest/services/Geocoder_BAG_RD/GeocodeServer",
			     name: "Geocoder",
			     singleLineFieldName: "SingleLine",
			     suffix: GetParam("search_gem"),
			     searchExtent: bounds,
			     placeholder: "Zoek adres of postcode"
			  }];
					  
			var geocoder = new esri.dijit.Geocoder({
			      map: map,
			      autoNavigate: false,
			      //autoComplete: true,
			      geocoders: gc,
			      geocoderMenu: false,
			      arcgisGeocoder: false
			  }, "searchMap");
			geocoder.startup();

			geocoder.on("find-results", showResults);				

			function showResults(results) {
			  var geom;
			  var zoomparam = GetParam("zoomlevel");			 
			  document.getElementById('adresnoresult').innerHTML = '';

			  var sortedresult = results.results.results.sort(function(a, b){
				    return b.feature.attributes.score-a.feature.attributes.score;
			   });
			   
			  geom = sortedresult[0].feature.geometry;
			  if (' '+sortedresult[0].name == GetParam("search_gem")) {
			   if (sortedresult.length == 1){
			     document.getElementById('adresnoresult').innerHTML = 'Adres <b>'+ document.getElementById('searchMap_input').value +'</b> niet gevonden!';
			   }
			   else if (sortedresult[1].feature.attributes.score > 80) {
			     ShowLocation(sortedresult[1].feature.geometry.x, sortedresult[1].feature.geometry.y,sortedresult[1].name);
			     geom = sortedresult[1].feature.geometry;
			     map.centerAndZoom(geom, zoomparam);
			     }
			   else {
			     document.getElementById('adresnoresult').innerHTML = 'Adres <b>'+ document.getElementById('searchMap_input').value +'</b> niet gevonden!';
			     }
			  }
			  else if (sortedresult[0].feature.attributes.score > 80) {
					ShowLocation(sortedresult[0].feature.geometry.x, sortedresult[0].feature.geometry.y,sortedresult[0].name);
					geom = sortedresult[0].feature.geometry;
					map.centerAndZoom(geom, zoomparam);
			  }
			  else {
			     document.getElementById('adresnoresult').innerHTML = 'Adres <b>'+ document.getElementById('searchMap_input').value +'</b> niet gevonden!';
			  }
			}
	   }
      	);

        function ShowLocation(x, y, label) {
            map.graphics.clear();
            var symbol = new esri.symbol.SimpleMarkerSymbol();
	      symbol.setPath("M16,3.5c-4.142,0-7.5,3.358-7.5,7.5c0,4.143,7.5,18.121,7.5,18.121S23.5,15.143,23.5,11C23.5,6.858,20.143,3.5,16,3.5z M16,14.584c-1.979,0-3.584-1.604-3.584-3.584S14.021,7.416,16,7.416S19.584,9.021,19.584,11S17.979,14.584,16,14.584z");
	      symbol.setColor(new dojo.Color("#660066"));
	      symbol.setSize("16pt");
	      symbol.setOffset(0,9);
	      symbol.setOutline(null);
	    
            var point = new esri.geometry.Point(x, y, new esri.SpatialReference({ wkid: 28992 }));            
            map.graphics.add(new esri.Graphic(point, symbol));            
            
	    //add a text symbol to the map listing the location of the matched address.	  
	    var displayTextArray = label.split(",");
	    var displayText = displayTextArray[0];
	    var font = new esri.symbol.Font("12pt", esri.symbol.Font.STYLE_NORMAL, esri.symbol.Font.VARIANT_NORMAL, esri.symbol.Font.WEIGHT_NORMAL,"Arial");
            
	    var textSymbol = new esri.symbol.TextSymbol(displayText,font,new dojo.Color("#660066"));
	    textSymbol.setOffset(0,23);	    
	    map.graphics.add(new esri.Graphic(point, textSymbol));            
        }
        
        function ToonLegenda(toonofniet)
        {
		  if (toonofniet=='none') {
			  document.getElementById('legenddiv').style.display = 'inline';
		  }
		  else if (toonofniet=='') {
			  document.getElementById('legenddiv').style.display = 'inline';
		  }
		  else {
			  document.getElementById('legenddiv').style.display = 'none';
		  }
        }


	  
